-------------------------------------------------------------------------------
-- Locals                                                                    --
-------------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("ClosetGnomeMount")
local lastSetBeforeMounting = nil

-------------------------------------------------------------------------------
-- Localization                                                              --
-------------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Mount"] = true,
	["Could not find a set named %s. Please add one."] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
	["Mount"] = "骑乘换装",
	["Could not find a set named %s. Please add one."] = "无法找到名为 %s 的设置. 请添加一个.",
} end)

L:RegisterTranslations("koKR", function() return {
	["Mount"] = "탈것",
	["Could not find a set named %s. Please add one."] = "세트 이름 %s|1을;를 찾을수 없습니다. 하나를 추가하세요.",
} end)

-------------------------------------------------------------------------------
-- Addon declaration                                                         --
-------------------------------------------------------------------------------

ClosetGnomeMount = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "AceEvent-2.0", "AceHook-2.1")
ClosetGnomeMount:RegisterDB("ClosetGnomeMountDB")
ClosetGnomeMount:RegisterDefaults("profile", {
	enabled = true,
})

-------------------------------------------------------------------------------
-- Initialization                                                            --
-------------------------------------------------------------------------------

function ClosetGnomeMount:OnEnable()
	if not ClosetGnome then return end
	self:RegisterEvent("SpecialEvents_Mounted")
	self:RegisterEvent("SpecialEvents_Dismounted")
	self:RegisterEvent("ClosetGnome_WearSet")
	self:Hook(ClosetGnome, "HideSetFromUI")

	if not ClosetGnome:HasSet(L["Mount"]) and self.db.profile.enabled then
		self:Print(string.format(L["Could not find a set named %s. Please add one."], L["Mount"]))
	else
		-- Force a menu update to hide the mount set properly.
		ClosetGnome:UpdateSetMenu()
	end
end

-------------------------------------------------------------------------------
-- Events                                                                    --
-------------------------------------------------------------------------------

function ClosetGnomeMount:HideSetFromUI(_, set)
	if set and set == L["Mount"] then
		return true
	end
	return self.hooks[ClosetGnome]["HideSetFromUI"](_, set)
end

function ClosetGnomeMount:ClosetGnome_WearSet(name)
	if name == L["Mount"] then return end
	lastSetBeforeMounting = name
end

function ClosetGnomeMount:SpecialEvents_Mounted()
	if not self.db.profile.enabled then return end
	if not ClosetGnome:HasSet(L["Mount"]) then
		self:Print(string.format(L["Could not find a set named %s. Please add one."], L["Mount"]))
		return
	end
	ClosetGnome:WearSet(L["Mount"])
end

function ClosetGnomeMount:SpecialEvents_Dismounted()
	if not ClosetGnome:HasSet(L["Mount"]) or not lastSetBeforeMounting or not self.db.profile.enabled then return end
	if ClosetGnome:HasSet(lastSetBeforeMounting) then
		ClosetGnome:WearSet(lastSetBeforeMounting)
	end
end

